<template>
  <!-- 搜索 -->
  <ContentWrap>
    <el-form
      class="-mb-15px"
      :model="queryParams"
      ref="queryFormRef"
      :inline="true"
      label-width="68px"
    >
      <el-form-item label="配置名称" prop="configName">
        <el-input
          v-model="queryParams.configName"
          placeholder="请输入名称"
          clearable
          @keyup.enter="handleQuery"
          class="!w-240px"
        />
      </el-form-item>
      <el-form-item label="配置编码" prop="configCode">
        <el-input
          v-model="queryParams.configCode"
          placeholder="请输入编码"
          clearable
          @keyup.enter="handleQuery"
          class="!w-240px"
        />
      </el-form-item>
      <el-form-item>
        <el-button @click="handleQuery">
          <Icon icon="ep:search" class="mr-5px" />
          搜索
        </el-button>
        <el-button @click="resetQuery">
          <Icon icon="ep:refresh" class="mr-5px" />
          重置
        </el-button>
        <el-button
          type="primary"
          plain
          @click="openForm('create')"
          v-hasPermi="['pre:auto-adjust-config:create']"
        >
          <Icon icon="ep:plus" class="mr-5px" />
          新增
        </el-button>
      </el-form-item>
    </el-form>
  </ContentWrap>

  <!-- 列表 -->
  <ContentWrap>
    <el-table v-loading="loading" :data="list">
      <el-table-column label="配置名称" header-align="center" align="center" min-width="150" prop="configName" fixed/>
      <el-table-column label="配置编码" header-align="center" align="center" min-width="150" prop="configCode" />
      <el-table-column label="预测项" header-align="center" align="center" min-width="150" prop="itemName" />
      <el-table-column label="输出" header-align="center" align="center" min-width="150" prop="outputName" />
      <el-table-column label="触发规则" align="center" min-width="60" prop="triggerRule">
        <template #default="scope">
          <dict-tag :type="DICT_TYPE.ADJUST_TRIGGER_RULE" :value="scope.row.triggerRule" />
        </template>
      </el-table-column>
      <el-table-column label="触发值" header-align="center" align="center" min-width="60" prop="triggerValue" />
      <el-table-column label="调整值计算规则" align="center" min-width="100" prop="adjustValueRule">
        <template #default="scope">
          <dict-tag :type="DICT_TYPE.ADJUST_VALUE_RULE" :value="scope.row.adjustValueRule" />
        </template>
      </el-table-column>
      <el-table-column label="调整方向" header-align="center" min-width="60" align="center" prop="adjustDirection" >
        <template #default="scope">
          <dict-tag :type="DICT_TYPE.ADJUST_DIRECTION" :value="scope.row.adjustDirection" />
        </template>
      </el-table-column>
      <el-table-column label="调整长度" header-align="center" align="center" min-width="60" prop="adjustLength" />
      <el-table-column label="调整系数" header-align="center" align="center" min-width="60" prop="adjustCoefficient" />
      <el-table-column label="是否启用" header-align="center" align="center" min-width="100" prop="isEnable" >
        <template #default="scope">
          <dict-tag :type="DICT_TYPE.COM_IS_INT" :value="scope.row.isEnable" />
        </template>
      </el-table-column>
      <el-table-column label="操作" align="center" min-width="160" fixed="right">
        <template #default="scope">
          <el-button
            link
            type="primary"
            @click="openForm('update', scope.row.id)"
            v-hasPermi="['pre:auto-adjust-config:update']"
          >
            编辑
          </el-button>
          <el-button
            link
            type="danger"
            @click="handleDelete(scope.row.id)"
            v-hasPermi="['pre:auto-adjust-config:delete']"
          >
            删除
          </el-button>
        </template>
      </el-table-column>
    </el-table>
    <!-- 分页 -->
    <Pagination
      :total="total"
      v-model:page="queryParams.pageNo"
      v-model:limit="queryParams.pageSize"
      @pagination="getList"
    />
  </ContentWrap>

  <!-- 表单弹窗：添加/修改 -->
  <MmPredictAutoAdjustConfigForm ref="formRef" @success="getList" />

</template>
<script lang="ts" setup>
import MmPredictAutoAdjustConfigForm from './MmPredictAutoAdjustConfigForm.vue'
import * as AutoAdjustConfigApi from '@/api/model/pre/autoAdjust/config'
import {DICT_TYPE} from "@/utils/dict";

defineOptions({name: 'autoAdjust'})

  const message = useMessage() // 消息弹窗
  const {t} = useI18n() // 国际化

  const loading = ref(true) // 列表的加载中
  const total = ref(0) // 列表的总页数
  const list = ref([]) // 列表的数据
  const queryParams = reactive({
    pageNo: 1,
    pageSize: 10,
    configName: undefined,
    configCode: undefined,
  })
  const queryFormRef = ref() // 搜索的表单

  /** 查询列表 */
  const getList = async () => {
    loading.value = true
    try {
      const page = await AutoAdjustConfigApi.getPage(queryParams)
      list.value = page.list
      total.value = page.total
    } finally {
      loading.value = false
    }
  }

  /** 搜索按钮操作 */
  const handleQuery = () => {
    queryParams.pageNo = 1
    getList()
  }

  /** 重置按钮操作 */
  const resetQuery = () => {
    queryFormRef.value.resetFields()
    handleQuery()
  }

  /** 添加/修改操作 */
  const formRef = ref()
  const openForm = (type: string, id?: number) => {
    formRef.value.open(type, id)
  }

  /** 删除按钮操作 */
  const handleDelete = async (id: number) => {
    try {
      // 删除的二次确认
      await message.delConfirm()
      // 发起删除
      await AutoAdjustConfigApi.deleteConfig(id)
      message.success(t('common.delSuccess'))
      // 刷新列表
      await getList()
    } catch {
    }
  }

  /** 初始化 **/
  onMounted(async () => {
    await getList()
  })
</script>
